#!/usr/bin/env perl

use strict qw(vars refs subs);
use Meta::Utils::System qw();
use Meta::Utils::Opts::Opts qw();
use Meta::Baseline::Test qw();
use Meta::Utils::File::File qw();
use Meta::Utils::Output qw();

my($opts)=Meta::Utils::Opts::Opts->new();
$opts->set_standard();
$opts->set_free_allo(0);
$opts->analyze(\@ARGV);

Meta::Baseline::Test::redirect_on();

my($file)="xmlx/README.dir";
my($abs)=Meta::Baseline::Aegis::which($file);

Meta::Utils::Output::print("reading with load_deve\n");
my($text1);
Meta::Utils::File::File::load_deve($file,\$text1);
#Meta::Utils::Output::print("text is [".$text1."]\n");
Meta::Utils::Output::print("size is [".length($text1)."]\n");

Meta::Utils::Output::print("reading with load\n");
my($text2);
Meta::Utils::File::File::load($abs,\$text2);
#Meta::Utils::Output::print("text is [".$text2."]\n");
Meta::Utils::Output::print("size is [".length($text2)."]\n");

Meta::Utils::Output::print("reading with load_nodie\n");
my($text3);
Meta::Utils::File::File::load_nodie($abs,\$text3);
#Meta::Utils::Output::print("text is [".$text3."]\n");
Meta::Utils::Output::print("size is [".length($text3)."]\n");

Meta::Utils::Output::print("reading with old_load\n");
my($text4);
Meta::Utils::File::File::old_load($abs,\$text4);
#Meta::Utils::Output::print("text is [".$text4."]\n");
Meta::Utils::Output::print("size is [".length($text4)."]\n");

Meta::Baseline::Test::redirect_off();

Meta::Utils::System::exit_ok();

__END__

=head1 NAME

file.pl - test the Meta::Utils::File::File module.

=head1 COPYRIGHT

Copyright (C) 2001, 2002 Mark Veltzer;
All rights reserved.

=head1 LICENSE

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.

=head1 DETAILS

	MANIFEST: file.pl
	PROJECT: meta
	VERSION: 0.03

=head1 SYNOPSIS

	file.pl [options]

=head1 DESCRIPTION

This program is a small test suite for the Meta::Utils::File::File module.

=head1 OPTIONS

=over 4

=item B<help> (type: bool, default: 0)

display help message

=item B<pod> (type: bool, default: 0)

display pod options snipplet

=item B<man> (type: bool, default: 0)

display manual page

=item B<quit> (type: bool, default: 0)

quit without doing anything

=item B<gtk> (type: bool, default: 0)

run a gtk ui to get the parameters

=item B<license> (type: bool, default: 0)

show license and exit

=item B<copyright> (type: bool, default: 0)

show copyright and exit

=item B<description> (type: bool, default: 0)

show description and exit

=item B<history> (type: bool, default: 0)

show history and exit

=back

no free arguments are allowed

=head1 BUGS

None.

=head1 AUTHOR

	Name: Mark Veltzer
	Email: mailto:veltzer@cpan.org
	WWW: http://www.veltzer.org
	CPAN id: VELTZER

=head1 HISTORY

	0.00 MV web site automation
	0.01 MV SEE ALSO section fix
	0.02 MV move tests to modules
	0.03 MV md5 issues

=head1 SEE ALSO

Meta::Baseline::Test(3), Meta::Utils::File::File(3), Meta::Utils::Opts::Opts(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)

=head1 TODO

Nothing.
